summaryrefslogtreecommitdiffstats
path: root/experimental/tqtinterface/qt4/src/widgets/tqcheckbox.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-07-17 19:19:26 -0500
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-07-17 19:19:26 -0500
commit07b6965cbac26077a27faf4071487d9a25fb3aa0 (patch)
tree8c5910ccfcab2269f7948dbd74a83048cd99d2ac /experimental/tqtinterface/qt4/src/widgets/tqcheckbox.cpp
parent1c210202b89d0161f34432bc74157a278670f4dc (diff)
downloadtde-07b6965cbac26077a27faf4071487d9a25fb3aa0.tar.gz
tde-07b6965cbac26077a27faf4071487d9a25fb3aa0.zip
Revert "Rename tqsize* to size*"
This reverts commit e33879600503bacc0b4ef090f7f79ab80bb6b0da.
Diffstat (limited to 'experimental/tqtinterface/qt4/src/widgets/tqcheckbox.cpp')
-rw-r--r--experimental/tqtinterface/qt4/src/widgets/tqcheckbox.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/experimental/tqtinterface/qt4/src/widgets/tqcheckbox.cpp b/experimental/tqtinterface/qt4/src/widgets/tqcheckbox.cpp
index 0b139bf95..37e8eac97 100644
--- a/experimental/tqtinterface/qt4/src/widgets/tqcheckbox.cpp
+++ b/experimental/tqtinterface/qt4/src/widgets/tqcheckbox.cpp
@@ -170,16 +170,16 @@ bool TQCheckBox::isTristate() const
/*!\reimp
*/
-TQSize TQCheckBox::sizeHint() const
+TQSize TQCheckBox::tqsizeHint() const
{
// NB: TQRadioButton::sizeHint() is similar
constPolish();
TQPainter p(this);
TQSize sz = tqstyle().tqitemRect(&p, TQRect(0, 0, 1, 1), TQt::ShowPrefix, FALSE,
pixmap(), text()).size();
- return (tqstyle().sizeFromContents(TQStyle::CT_CheckBox, this, sz).
+ return (tqstyle().tqsizeFromContents(TQStyle::CT_CheckBox, this, sz).
expandedTo(TQApplication::globalStrut()));
}
@@ -316,7 +316,7 @@ void TQCheckBox::resizeEvent( TQResizeEvent *e )
TQPainter p(this);
TQSize isz = tqstyle().tqitemRect(&p, TQRect(0, 0, 1, 1), TQt::ShowPrefix, FALSE,
pixmap(), text()).size();
- TQSize wsz = (tqstyle().sizeFromContents(TQStyle::CT_CheckBox, this, isz).
+ TQSize wsz = (tqstyle().tqsizeFromContents(TQStyle::CT_CheckBox, this, isz).
expandedTo(TQApplication::globalStrut()));
update(wsz.width(), isz.width(), 0, wsz.height());
@@ -170,16 +170,16 @@ bool TQCheckBox::isTristate() const
{
- // NB: TQRadioButton::sizeHint() is similar
+ // NB: TQRadioButton::tqsizeHint() is similar
constPolish();
TQPainter p(this);